@@ -6,7 +6,11 @@ run_local <- function(responses, nfact, start_item, nitems, thetas.start_in,
         if(is.na(start_item)) design@start_item <- sample(1L:ncol(responses), 1L)
         person <- Person$new(nfact=nfact, nitems=nitems, theta_SEs=sqrt(diag(test@gp$gcov)),
                              thetas.start_in=thetas.start_in, score=score)
-        item <- findNextCATItem(person=person, test=test, design=design)
+        item <- findNextCATItem(person=person, test=test, design=design, criteria=design@criteria)
+        if(is.na(item)){
+            design@stop_now <- TRUE
+            return(person)
+        }
         person$items_answered[1L] <- item
         
         for(i in 2L:(ncol(responses)+1L)){
@@ -27,7 +31,12 @@ run_local <- function(responses, nfact, start_item, nitems, thetas.start_in,
             
             design <- Next.stage(design, person=person, test=test, item=i)
             
-            item <- findNextCATItem(person=person, test=test, design=design)
+            item <- findNextCATItem(person=person, test=test, design=design, 
+                                    criteria=design@criteria)
+            if(is.na(item)){
+                design@stop_now <- TRUE
+                break
+            } 
             person$items_answered[i] <- item
         }
         return(person)
